@@ -96,41 +96,44 @@ GdkFilterReturn<-c("continue" = 0,
 storage.mode(GdkFilterReturn) <- 'integer'
 class(GdkFilterReturn) <- 'enums' 
 
-GdkEventType<-c("nothing" = 0,
-	"delete" = 1,
-	"destroy" = 2,
-	"expose" = 3,
-	"motion-notify" = 4,
-	"button-press" = 5,
-	"2button-press" = 6,
-	"3button-press" = 7,
-	"button-release" = 8,
-	"key-press" = 9,
-	"key-release" = 10,
-	"enter-notify" = 11,
-	"leave-notify" = 12,
-	"focus-change" = 13,
-	"configure" = 14,
-	"map" = 15,
-	"unmap" = 16,
-	"property-notify" = 17,
-	"selection-clear" = 18,
-	"selection-request" = 19,
-	"selection-notify" = 20,
-	"proximity-in" = 21,
-	"proximity-out" = 22,
-	"drag-enter" = 23,
-	"drag-leave" = 24,
-	"drag-motion" = 25,
-	"drag-status" = 26,
-	"drop-start" = 27,
-	"drop-finished" = 28,
-	"client-event" = 29,
-	"visibility-notify" = 30,
-	"no-expose" = 31,
-	"scroll" = 32,
-	"window-state" = 33,
-	"setting" = 34)
+GdkEventType<-c("nothing" = -1,
+	"delete" = 0,
+	"destroy" = 1,
+	"expose" = 2,
+	"motion-notify" = 3,
+	"button-press" = 4,
+	"2button-press" = 5,
+	"3button-press" = 6,
+	"button-release" = 7,
+	"key-press" = 8,
+	"key-release" = 9,
+	"enter-notify" = 10,
+	"leave-notify" = 11,
+	"focus-change" = 12,
+	"configure" = 13,
+	"map" = 14,
+	"unmap" = 15,
+	"property-notify" = 16,
+	"selection-clear" = 17,
+	"selection-request" = 18,
+	"selection-notify" = 19,
+	"proximity-in" = 20,
+	"proximity-out" = 21,
+	"drag-enter" = 22,
+	"drag-leave" = 23,
+	"drag-motion" = 24,
+	"drag-status" = 25,
+	"drop-start" = 26,
+	"drop-finished" = 27,
+	"client-event" = 28,
+	"visibility-notify" = 29,
+	"no-expose" = 30,
+	"scroll" = 31,
+	"window-state" = 32,
+	"setting" = 33,
+	"owner-change" = 34,
+	"grab-broken" = 35,
+	"gdk-damage" = 36)
 storage.mode(GdkEventType) <- 'integer'
 class(GdkEventType) <- 'enums' 
 
